==> smart_arrays_plot_polyline-2.0.0.tar.gz: example/sample_data.dart <==
import 'dart:typed_data';
import 'dart:math' as math;

class SampleData {
  /**
   * Compute sample sin(x) function with amplitude [yscal] and phase [phase] in rad.
   * The number of periods in the display and the point resolution are defined by  NPERIODS, NXVALUES
   * Returns a list with 2 entries: The array of x values and the array of y values.
   */
  static List<Float64List> genSine(
      double ampl, double offset, double phase, int nperiods, int nxvalues, bool isComplex) {
    double xmax = 2 * math.pi * nperiods;
//    List<Float64List> sine = new List<Float64List>();
    Float64List xValues = new Float64List(nxvalues);
    Float64List yValues = new Float64List(nxvalues);
    double x, y, yim = ampl;
    double yscal = 1.0;

    if (isComplex) nxvalues ~/= 2;

    for (int i = 0; i < nxvalues; i++) {
      x = (i * xmax) / nxvalues;
      y = ampl*yscal * math.sin(x + phase);
      yim = ampl*yscal * math.sin(x + phase + math.pi / 2);
      xValues[i] = x;
      yValues[i] = y+offset;
      if (isComplex) {
        xValues[i] = x;
        yValues[i] = yim+offset;
      }
    }

    return [xValues, yValues];
  }

  /**
   * Compute sample sin(x)/x function with amplitude [yscal] and phase [phase].
   * The number of periods in the display and the point resolution are defined by  NPERIODS, NXVALUES.
   * Returns a list with 2 entries: The array of x values and the array of y values.
   */
  static List<Float64List> genSinc(
      double ampl, double phase, int nperiods, int nxvalues, bool isComplex) {
    double xmax = 2 * math.pi * nperiods;

//    List<Float64List> sine = new List<Float64List>();
    Float64List xValues = new Float64List(nxvalues);
    Float64List yValues = new Float64List(nxvalues);
    double x, y, yim, a;

    a = ampl;
    double yscal = 1.0;
    if (isComplex) nxvalues ~/= 2;

    for (int i = 0; i < nxvalues; i++) {
      x = (i * xmax) / nxvalues;
      if (i == 0 && phase.abs() < 0.00001) {
        y = a * yscal;
        yim = y;
      } else {
        double ph = x + phase;
        y = a * yscal * math.sin(ph) / ph;
        if (isComplex) {
          double ph = x + phase + math.pi / 2;
          yim = a * yscal * math.sin(ph) / ph;
        }
      }
      xValues[i] = x;
      yValues[i] = y;
      if (isComplex) {
        xValues[i] = x;
        yValues[i] = yim;
      }
    }
    return [xValues, yValues];
  }


}

==> smart_arrays_plot_polyline-2.0.6.tar.gz: example/sample_data.dart <==
import 'dart:typed_data';
import 'dart:math' as math;

class SampleData {
  /// Compute sample sin(x) function with amplitude [yscal] and phase [phase] in rad.
  ///  The number of periods in the display and the point resolution are defined
  ///  by  NPERIODS, NXVALUES.
  ///  Returns a list with 2 entries: The array of x values and the array of y values.
  static List<Float64List> genSine(
      double ampl, double offset, double phase, int nperiods, int nxvalues, bool isComplex) {
    double xmax = 2 * math.pi * nperiods;
//    List<Float64List> sine = new List<Float64List>();
    Float64List xValues = new Float64List(nxvalues);
    Float64List yValues = new Float64List(nxvalues);
    double x, y, yim = ampl;
    double yscal = 1.0;

    if (isComplex) nxvalues ~/= 2;

    for (int i = 0; i < nxvalues; i++) {
      x = (i * xmax) / nxvalues;
      y = ampl*yscal * math.sin(x + phase);
      yim = ampl*yscal * math.sin(x + phase + math.pi / 2);
      xValues[i] = x;
      yValues[i] = y+offset;
      if (isComplex) {
        xValues[i] = x;
        yValues[i] = yim+offset;
      }
    }

    return [xValues, yValues];
  }

  /// Compute sample sin(x)/x function with amplitude [yscal] and phase [phase].
  /// The number of periods in the display and the point resolution are defined
  /// by  NPERIODS, NXVALUES.
  ///  Returns a list with 2 entries: The array of x values and the array of y values.
  static List<Float64List> genSinc(
      double ampl, double phase, int nperiods, int nxvalues, bool isComplex) {
    double xmax = 2 * math.pi * nperiods;

//    List<Float64List> sine = new List<Float64List>();
    Float64List xValues = new Float64List(nxvalues);
    Float64List yValues = new Float64List(nxvalues);
    double x, y, yim, a;

    a = ampl;
    double yscal = 1.0;
    if (isComplex) nxvalues ~/= 2;

    for (int i = 0; i < nxvalues; i++) {
      x = (i * xmax) / nxvalues;
      if (i == 0 && phase.abs() < 0.00001) {
        y = a * yscal;
        yim = y;
      } else {
        double ph = x + phase;
        y = a * yscal * math.sin(ph) / ph;
        if (isComplex) {
          double ph = x + phase + math.pi / 2;
          yim = a * yscal * math.sin(ph) / ph;
        }
      }
      xValues[i] = x;
      yValues[i] = y;
      if (isComplex) {
        xValues[i] = x;
        yValues[i] = yim;
      }
    }
    return [xValues, yValues];
  }


}
